==> neo4j-server-4.4.19-sources.jar: org/neo4j/server/http/HttpMemoryPool.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.server.http;

import org.eclipse.jetty.io.ArrayByteBufferPool;

import org.neo4j.memory.GlobalMemoryGroupTracker;
import org.neo4j.memory.MemoryPools;

import static org.neo4j.memory.MemoryGroup.HTTP;

public class HttpMemoryPool extends GlobalMemoryGroupTracker
{
    private final ArrayByteBufferPool byteBufferPool;

    public HttpMemoryPool( MemoryPools memoryPools, ArrayByteBufferPool byteBufferPool )
    {
        super( memoryPools, HTTP, 0, false, true, null );
        this.byteBufferPool = byteBufferPool;

        memoryPools.registerPool( this );
    }

    @Override
    public long usedHeap()
    {
        return super.usedHeap() + byteBufferPool.getHeapMemory();
    }

    @Override
    public long usedNative()
    {
        return super.usedNative() + byteBufferPool.getDirectMemory();
    }
}

==> neo4j-server-5.3.0-sources.jar: org/neo4j/server/http/HttpMemoryPool.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.server.http;

import static org.neo4j.memory.MemoryGroup.HTTP;

import org.eclipse.jetty.io.ArrayByteBufferPool;
import org.neo4j.memory.GlobalMemoryGroupTracker;
import org.neo4j.memory.MemoryPools;

public class HttpMemoryPool extends GlobalMemoryGroupTracker {
    private final ArrayByteBufferPool byteBufferPool;

    public HttpMemoryPool(MemoryPools memoryPools, ArrayByteBufferPool byteBufferPool) {
        super(memoryPools, HTTP, 0, false, true, null);
        this.byteBufferPool = byteBufferPool;

        memoryPools.registerPool(this);
    }

    @Override
    public long usedHeap() {
        return super.usedHeap() + byteBufferPool.getHeapMemory();
    }

    @Override
    public long usedNative() {
        return super.usedNative() + byteBufferPool.getDirectMemory();
    }
}
